@@ -19,7 +19,6 @@
 import chess
 import itertools
 import re
-import sys
 
 try:
     import backport_collections as collections
@@ -100,17 +99,23 @@ class GameNode(object):
 
         self.board_cached = None
 
-    def board(self):
+    def board(self, _cache=True):
         """
         Gets a board with the position of the node.
 
         It's a copy, so modifying the board will not alter the game.
         """
-        if not self.board_cached:
-            self.board_cached = self.parent.board()
-            self.board_cached.push(self.move)
+        if self.board_cached:
+            return self.board_cached.copy()
 
-        return self.board_cached.copy()
+        board = self.parent.board(_cache=False)
+        board.push(self.move)
+
+        if _cache:
+            self.board_cached = board
+            return board.copy()
+        else:
+            return board
 
     def san(self):
         """
@@ -138,6 +143,10 @@ class GameNode(object):
 
         return node
 
+    def is_end(self):
+        """Checks if this node is the last node in the current variation."""
+        return not self.variations
+
     def starts_variation(self):
         """
         Checks if this node starts a variation (and can thus have a starting
@@ -341,7 +350,7 @@ class Game(GameNode):
 
         self.errors = []
 
-    def board(self):
+    def board(self, _cache=False):
         """
         Gets the starting position of the game.
 
@@ -483,7 +492,7 @@ class StringExporter(object):
 
     def __str__(self):
         if self.current_line:
-            return "\n".join(itertools.chain(self.lines, [ self.current_line.rstrip() ] )).rstrip()
+            return "\n".join(itertools.chain(self.lines, [self.current_line.rstrip()])).rstrip()
         else:
             return "\n".join(self.lines).rstrip()
 
@@ -621,7 +630,7 @@ def read_game(handle, error_handler=_raise):
             if token.startswith("{"):
                 # Consume until the end of the comment.
                 line = token[1:]
-                comment_lines = [ ]
+                comment_lines = []
                 while line and "}" not in line:
                     comment_lines.append(line.rstrip())
                     line = handle.readline()
@@ -759,7 +768,6 @@ def scan_headers(handle):
     last_pos = handle.tell()
     line = handle.readline()
 
-
     while line:
         # Skip single line comments.
         if line.startswith("%"):
